@@ -5,7 +5,7 @@ class createTemplate(UcloudAPI):
     params = {	'displaytext' : [True,None],
               	'name'       : [True,None],
       		'ostypeid'    	: [True,None],
-      		'bit'    : [True,None],
+      		'bits'    : [False,None],
       		'details'            : [False,None],
       		'isfeatured'       : [False,None],
       		'ispublic'          : [False,None],
